## Installation

You can install this package using one of the following options:

```bash
pip install git+https://github.com/MaxusTheOne/napari-psf-analysis-CFIM-edition
```

or

```bash
pip install psf-analysis-CFIM
```

---

## About

This is a **fork** of the [napari-psf-analysis](https://github.com/fmi-faim/napari-psf-analysis) project.

---

## Extra Features

This edition includes the following additional features:

- **CZI Reader**: Adds support for reading CZI image files.
- **Auto-Filling of Plugin Parameters**: Automatically populates parameters for the plugin.
- **Auto Analysis of Image for PSF**: Performs automatic image analysis for PSFs.
- Might crash on any filer other than CZI... ups.
